@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,20 +41,21 @@ CPL_BEGIN_DECLS
  * The values can be combined with bitwise or.
  */
 
-enum _cpl_fits_mode_ {
+enum _cpl_fits_mode_
+{
 
-/* No mode has the value 1, which makes the (mis)use of logical or detectable */
+    /* No mode has the value 1, which makes the (mis)use of logical or detectable */
 
     /**
      * Stop the caching of open FITS files
      * @hideinitializer
      */
-    CPL_FITS_STOP_CACHING =  1 << 1,
+    CPL_FITS_STOP_CACHING = 1 << 1,
     /**
      * Start the caching of open FITS files
      * @hideinitializer
      */
-    CPL_FITS_START_CACHING =  1 << 2,
+    CPL_FITS_START_CACHING = 1 << 2,
     /**
      * Restart the caching of open FITS files
      * @hideinitializer
@@ -64,8 +65,8 @@ enum _cpl_fits_mode_ {
      * Apply the mode change only to the current thread
      * @hideinitializer
      */
-    CPL_FITS_ONE =  1 << 3
- 
+    CPL_FITS_ONE = 1 << 3
+
 };
 
 /**
@@ -92,4 +93,4 @@ int cpl_fits_get_extension_nb(const char *, const char *) CPL_ATTR_DEPRECATED;
 
 CPL_END_DECLS
 
-#endif 
+#endif
