@@ -1,7 +1,6 @@
-/* $Id: cpl_image_bpm.h,v 1.20 2012-12-07 13:51:34 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-12-07 13:51:34 $
- * $Revision: 1.20 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_IMAGE_BPM_H
 #define CPL_IMAGE_BPM_H
 
@@ -49,40 +41,41 @@ CPL_BEGIN_DECLS
  * They are a bit-field and can be combined with bitwise or.
  */
 
-enum _cpl_value_ {
+enum _cpl_value_
+{
 
-/* No entry has the value 1 which makes the (mis)use of logical or detectable */
+    /* No entry has the value 1 which makes the (mis)use of logical or detectable */
 
     /**
      * Not-a-Number (NaN)
      * @hideinitializer
      */
-    CPL_VALUE_NAN        =  1 << 1,
+    CPL_VALUE_NAN = 1 << 1,
     /**
      * Plus Infinity
      * @hideinitializer
      */
-    CPL_VALUE_PLUSINF    =  1 << 2,
+    CPL_VALUE_PLUSINF = 1 << 2,
     /**
      * Minus Infinity
      * @hideinitializer
      */
-    CPL_VALUE_MINUSINF   =  1 << 3,
+    CPL_VALUE_MINUSINF = 1 << 3,
     /**
      * Zero
      * @hideinitializer
      */
-    CPL_VALUE_ZERO       =  1 << 4,
+    CPL_VALUE_ZERO = 1 << 4,
     /**
      * Infinity with any sign
      * @hideinitializer
      */
-    CPL_VALUE_INF        =  CPL_VALUE_PLUSINF | CPL_VALUE_MINUSINF,
+    CPL_VALUE_INF = CPL_VALUE_PLUSINF | CPL_VALUE_MINUSINF,
     /**
      * NaN or infinity with any sign
      * @hideinitializer
      */
-    CPL_VALUE_NOTFINITE  =  CPL_VALUE_INF | CPL_VALUE_NAN
+    CPL_VALUE_NOTFINITE = CPL_VALUE_INF | CPL_VALUE_NAN
 };
 
 
@@ -95,7 +88,6 @@ enum _cpl_value_ {
 typedef enum _cpl_value_ cpl_value;
 
 
-
 /*-----------------------------------------------------------------------------
                             Function prototypes
  -----------------------------------------------------------------------------*/
@@ -113,4 +105,4 @@ cpl_error_code cpl_image_reject_value(cpl_image *, cpl_value);
 
 CPL_END_DECLS
 
-#endif 
+#endif
