@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,10 @@
 CPL_BEGIN_DECLS
 
 /* Load an image list from a frame set */
-cpl_imagelist * cpl_imagelist_load_frameset(const cpl_frameset *, cpl_type, 
-                                            cpl_size, cpl_size) CPL_ATTR_ALLOC;
+cpl_imagelist *cpl_imagelist_load_frameset(const cpl_frameset *,
+                                           cpl_type,
+                                           cpl_size,
+                                           cpl_size) CPL_ATTR_ALLOC;
 
 CPL_END_DECLS
 
